# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/ponsim.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/ponsim.proto',
  package='voltha',
  syntax='proto3',
  serialized_options=b'\n\023org.opencord.volthaZ.github.com/opencord/voltha-protos/v3/go/voltha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1avoltha_protos/ponsim.proto\x12\x06voltha\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fvoltha_protos/openflow_13.proto\">\n\x13PonSimOnuDeviceInfo\x12\x10\n\x08uni_port\x18\x01 \x01(\x05\x12\x15\n\rserial_number\x18\x02 \x01(\t\"O\n\x10PonSimDeviceInfo\x12\x10\n\x08nni_port\x18\x01 \x01(\x05\x12)\n\x04onus\x18\x02 \x03(\x0b\x32\x1b.voltha.PonSimOnuDeviceInfo\"E\n\tFlowTable\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12*\n\x05\x66lows\x18\x02 \x03(\x0b\x32\x1b.openflow_13.ofp_flow_stats\"<\n\x0bPonSimFrame\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x10\n\x08out_port\x18\x03 \x01(\x05\"2\n\x13PonSimPacketCounter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03\"T\n\x11PonSimPortMetrics\x12\x11\n\tport_name\x18\x01 \x01(\t\x12,\n\x07packets\x18\x02 \x03(\x0b\x32\x1b.voltha.PonSimPacketCounter\"K\n\rPonSimMetrics\x12\x0e\n\x06\x64\x65vice\x18\x01 \x01(\t\x12*\n\x07metrics\x18\x02 \x03(\x0b\x32\x19.voltha.PonSimPortMetrics\"$\n\x14PonSimMetricsRequest\x12\x0c\n\x04port\x18\x01 \x01(\x05\x32\xc8\x02\n\x06PonSim\x12:\n\tSendFrame\x12\x13.voltha.PonSimFrame\x1a\x16.google.protobuf.Empty\"\x00\x12@\n\rReceiveFrames\x12\x16.google.protobuf.Empty\x1a\x13.voltha.PonSimFrame\"\x00\x30\x01\x12\x43\n\rGetDeviceInfo\x12\x16.google.protobuf.Empty\x1a\x18.voltha.PonSimDeviceInfo\"\x00\x12>\n\x0fUpdateFlowTable\x12\x11.voltha.FlowTable\x1a\x16.google.protobuf.Empty\"\x00\x12;\n\x08GetStats\x12\x16.google.protobuf.Empty\x1a\x15.voltha.PonSimMetrics\"\x00\x42\x45\n\x13org.opencord.volthaZ.github.com/opencord/voltha-protos/v3/go/volthab\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,voltha__protos_dot_openflow__13__pb2.DESCRIPTOR,])




_PONSIMONUDEVICEINFO = _descriptor.Descriptor(
  name='PonSimOnuDeviceInfo',
  full_name='voltha.PonSimOnuDeviceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uni_port', full_name='voltha.PonSimOnuDeviceInfo.uni_port', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='voltha.PonSimOnuDeviceInfo.serial_number', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=162,
)


_PONSIMDEVICEINFO = _descriptor.Descriptor(
  name='PonSimDeviceInfo',
  full_name='voltha.PonSimDeviceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nni_port', full_name='voltha.PonSimDeviceInfo.nni_port', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onus', full_name='voltha.PonSimDeviceInfo.onus', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=243,
)


_FLOWTABLE = _descriptor.Descriptor(
  name='FlowTable',
  full_name='voltha.FlowTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='voltha.FlowTable.port', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flows', full_name='voltha.FlowTable.flows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=314,
)


_PONSIMFRAME = _descriptor.Descriptor(
  name='PonSimFrame',
  full_name='voltha.PonSimFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.PonSimFrame.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='voltha.PonSimFrame.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='out_port', full_name='voltha.PonSimFrame.out_port', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=316,
  serialized_end=376,
)


_PONSIMPACKETCOUNTER = _descriptor.Descriptor(
  name='PonSimPacketCounter',
  full_name='voltha.PonSimPacketCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='voltha.PonSimPacketCounter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.PonSimPacketCounter.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=428,
)


_PONSIMPORTMETRICS = _descriptor.Descriptor(
  name='PonSimPortMetrics',
  full_name='voltha.PonSimPortMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_name', full_name='voltha.PonSimPortMetrics.port_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packets', full_name='voltha.PonSimPortMetrics.packets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=514,
)


_PONSIMMETRICS = _descriptor.Descriptor(
  name='PonSimMetrics',
  full_name='voltha.PonSimMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='voltha.PonSimMetrics.device', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='voltha.PonSimMetrics.metrics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=516,
  serialized_end=591,
)


_PONSIMMETRICSREQUEST = _descriptor.Descriptor(
  name='PonSimMetricsRequest',
  full_name='voltha.PonSimMetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='voltha.PonSimMetricsRequest.port', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=593,
  serialized_end=629,
)

_PONSIMDEVICEINFO.fields_by_name['onus'].message_type = _PONSIMONUDEVICEINFO
_FLOWTABLE.fields_by_name['flows'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_FLOW_STATS
_PONSIMPORTMETRICS.fields_by_name['packets'].message_type = _PONSIMPACKETCOUNTER
_PONSIMMETRICS.fields_by_name['metrics'].message_type = _PONSIMPORTMETRICS
DESCRIPTOR.message_types_by_name['PonSimOnuDeviceInfo'] = _PONSIMONUDEVICEINFO
DESCRIPTOR.message_types_by_name['PonSimDeviceInfo'] = _PONSIMDEVICEINFO
DESCRIPTOR.message_types_by_name['FlowTable'] = _FLOWTABLE
DESCRIPTOR.message_types_by_name['PonSimFrame'] = _PONSIMFRAME
DESCRIPTOR.message_types_by_name['PonSimPacketCounter'] = _PONSIMPACKETCOUNTER
DESCRIPTOR.message_types_by_name['PonSimPortMetrics'] = _PONSIMPORTMETRICS
DESCRIPTOR.message_types_by_name['PonSimMetrics'] = _PONSIMMETRICS
DESCRIPTOR.message_types_by_name['PonSimMetricsRequest'] = _PONSIMMETRICSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PonSimOnuDeviceInfo = _reflection.GeneratedProtocolMessageType('PonSimOnuDeviceInfo', (_message.Message,), {
  'DESCRIPTOR' : _PONSIMONUDEVICEINFO,
  '__module__' : 'voltha_protos.ponsim_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PonSimOnuDeviceInfo)
  })
_sym_db.RegisterMessage(PonSimOnuDeviceInfo)

PonSimDeviceInfo = _reflection.GeneratedProtocolMessageType('PonSimDeviceInfo', (_message.Message,), {
  'DESCRIPTOR' : _PONSIMDEVICEINFO,
  '__module__' : 'voltha_protos.ponsim_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PonSimDeviceInfo)
  })
_sym_db.RegisterMessage(PonSimDeviceInfo)

FlowTable = _reflection.GeneratedProtocolMessageType('FlowTable', (_message.Message,), {
  'DESCRIPTOR' : _FLOWTABLE,
  '__module__' : 'voltha_protos.ponsim_pb2'
  # @@protoc_insertion_point(class_scope:voltha.FlowTable)
  })
_sym_db.RegisterMessage(FlowTable)

PonSimFrame = _reflection.GeneratedProtocolMessageType('PonSimFrame', (_message.Message,), {
  'DESCRIPTOR' : _PONSIMFRAME,
  '__module__' : 'voltha_protos.ponsim_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PonSimFrame)
  })
_sym_db.RegisterMessage(PonSimFrame)

PonSimPacketCounter = _reflection.GeneratedProtocolMessageType('PonSimPacketCounter', (_message.Message,), {
  'DESCRIPTOR' : _PONSIMPACKETCOUNTER,
  '__module__' : 'voltha_protos.ponsim_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PonSimPacketCounter)
  })
_sym_db.RegisterMessage(PonSimPacketCounter)

PonSimPortMetrics = _reflection.GeneratedProtocolMessageType('PonSimPortMetrics', (_message.Message,), {
  'DESCRIPTOR' : _PONSIMPORTMETRICS,
  '__module__' : 'voltha_protos.ponsim_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PonSimPortMetrics)
  })
_sym_db.RegisterMessage(PonSimPortMetrics)

PonSimMetrics = _reflection.GeneratedProtocolMessageType('PonSimMetrics', (_message.Message,), {
  'DESCRIPTOR' : _PONSIMMETRICS,
  '__module__' : 'voltha_protos.ponsim_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PonSimMetrics)
  })
_sym_db.RegisterMessage(PonSimMetrics)

PonSimMetricsRequest = _reflection.GeneratedProtocolMessageType('PonSimMetricsRequest', (_message.Message,), {
  'DESCRIPTOR' : _PONSIMMETRICSREQUEST,
  '__module__' : 'voltha_protos.ponsim_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PonSimMetricsRequest)
  })
_sym_db.RegisterMessage(PonSimMetricsRequest)


DESCRIPTOR._options = None

_PONSIM = _descriptor.ServiceDescriptor(
  name='PonSim',
  full_name='voltha.PonSim',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=632,
  serialized_end=960,
  methods=[
  _descriptor.MethodDescriptor(
    name='SendFrame',
    full_name='voltha.PonSim.SendFrame',
    index=0,
    containing_service=None,
    input_type=_PONSIMFRAME,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReceiveFrames',
    full_name='voltha.PonSim.ReceiveFrames',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_PONSIMFRAME,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDeviceInfo',
    full_name='voltha.PonSim.GetDeviceInfo',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_PONSIMDEVICEINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFlowTable',
    full_name='voltha.PonSim.UpdateFlowTable',
    index=3,
    containing_service=None,
    input_type=_FLOWTABLE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStats',
    full_name='voltha.PonSim.GetStats',
    index=4,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_PONSIMMETRICS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PONSIM)

DESCRIPTOR.services_by_name['PonSim'] = _PONSIM

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import adapter_pb2 as voltha__protos_dot_adapter__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import logical_device_pb2 as voltha__protos_dot_logical__device__pb2
from voltha_protos import omci_alarm_db_pb2 as voltha__protos_dot_omci__alarm__db__pb2
from voltha_protos import omci_mib_db_pb2 as voltha__protos_dot_omci__mib__db__pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2
from voltha_protos import voltha_pb2 as voltha__protos_dot_voltha__pb2


class VolthaServiceStub(object):
    """
    Voltha APIs

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetMembership = channel.unary_unary(
                '/voltha.VolthaService/GetMembership',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_voltha__pb2.Membership.FromString,
                )
        self.UpdateMembership = channel.unary_unary(
                '/voltha.VolthaService/UpdateMembership',
                request_serializer=voltha__protos_dot_voltha__pb2.Membership.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetVoltha = channel.unary_unary(
                '/voltha.VolthaService/GetVoltha',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_voltha__pb2.Voltha.FromString,
                )
        self.ListCoreInstances = channel.unary_unary(
                '/voltha.VolthaService/ListCoreInstances',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_voltha__pb2.CoreInstances.FromString,
                )
        self.GetCoreInstance = channel.unary_unary(
                '/voltha.VolthaService/GetCoreInstance',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_voltha__pb2.CoreInstance.FromString,
                )
        self.ListAdapters = channel.unary_unary(
                '/voltha.VolthaService/ListAdapters',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_adapter__pb2.Adapters.FromString,
                )
        self.ListLogicalDevices = channel.unary_unary(
                '/voltha.VolthaService/ListLogicalDevices',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_logical__device__pb2.LogicalDevices.FromString,
                )
        self.GetLogicalDevice = channel.unary_unary(
                '/voltha.VolthaService/GetLogicalDevice',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_logical__device__pb2.LogicalDevice.FromString,
                )
        self.ListLogicalDevicePorts = channel.unary_unary(
                '/voltha.VolthaService/ListLogicalDevicePorts',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_logical__device__pb2.LogicalPorts.FromString,
                )
        self.GetLogicalDevicePort = channel.unary_unary(
                '/voltha.VolthaService/GetLogicalDevicePort',
                request_serializer=voltha__protos_dot_logical__device__pb2.LogicalPortId.SerializeToString,
                response_deserializer=voltha__protos_dot_logical__device__pb2.LogicalPort.FromString,
                )
        self.EnableLogicalDevicePort = channel.unary_unary(
                '/voltha.VolthaService/EnableLogicalDevicePort',
                request_serializer=voltha__protos_dot_logical__device__pb2.LogicalPortId.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DisableLogicalDevicePort = channel.unary_unary(
                '/voltha.VolthaService/DisableLogicalDevicePort',
                request_serializer=voltha__protos_dot_logical__device__pb2.LogicalPortId.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListLogicalDeviceFlows = channel.unary_unary(
                '/voltha.VolthaService/ListLogicalDeviceFlows',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_openflow__13__pb2.Flows.FromString,
                )
        self.UpdateLogicalDeviceFlowTable = channel.unary_unary(
                '/voltha.VolthaService/UpdateLogicalDeviceFlowTable',
                request_serializer=voltha__protos_dot_openflow__13__pb2.FlowTableUpdate.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateLogicalDeviceMeterTable = channel.unary_unary(
                '/voltha.VolthaService/UpdateLogicalDeviceMeterTable',
                request_serializer=voltha__protos_dot_openflow__13__pb2.MeterModUpdate.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListLogicalDeviceMeters = channel.unary_unary(
                '/voltha.VolthaService/ListLogicalDeviceMeters',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_openflow__13__pb2.Meters.FromString,
                )
        self.ListLogicalDeviceFlowGroups = channel.unary_unary(
                '/voltha.VolthaService/ListLogicalDeviceFlowGroups',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_openflow__13__pb2.FlowGroups.FromString,
                )
        self.UpdateLogicalDeviceFlowGroupTable = channel.unary_unary(
                '/voltha.VolthaService/UpdateLogicalDeviceFlowGroupTable',
                request_serializer=voltha__protos_dot_openflow__13__pb2.FlowGroupTableUpdate.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListDevices = channel.unary_unary(
                '/voltha.VolthaService/ListDevices',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.Devices.FromString,
                )
        self.ListDeviceIds = channel.unary_unary(
                '/voltha.VolthaService/ListDeviceIds',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_common__pb2.IDs.FromString,
                )
        self.ReconcileDevices = channel.unary_unary(
                '/voltha.VolthaService/ReconcileDevices',
                request_serializer=voltha__protos_dot_common__pb2.IDs.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetDevice = channel.unary_unary(
                '/voltha.VolthaService/GetDevice',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                )
        self.CreateDevice = channel.unary_unary(
                '/voltha.VolthaService/CreateDevice',
                request_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                )
        self.EnableDevice = channel.unary_unary(
                '/voltha.VolthaService/EnableDevice',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DisableDevice = channel.unary_unary(
                '/voltha.VolthaService/DisableDevice',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RebootDevice = channel.unary_unary(
                '/voltha.VolthaService/RebootDevice',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteDevice = channel.unary_unary(
                '/voltha.VolthaService/DeleteDevice',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ForceDeleteDevice = channel.unary_unary(
                '/voltha.VolthaService/ForceDeleteDevice',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DownloadImage = channel.unary_unary(
                '/voltha.VolthaService/DownloadImage',
                request_serializer=voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
                response_deserializer=voltha__protos_dot_common__pb2.OperationResp.FromString,
                )
        self.GetImageDownloadStatus = channel.unary_unary(
                '/voltha.VolthaService/GetImageDownloadStatus',
                request_serializer=voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.ImageDownload.FromString,
                )
        self.GetImageDownload = channel.unary_unary(
                '/voltha.VolthaService/GetImageDownload',
                request_serializer=voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.ImageDownload.FromString,
                )
        self.ListImageDownloads = channel.unary_unary(
                '/voltha.VolthaService/ListImageDownloads',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.ImageDownloads.FromString,
                )
        self.CancelImageDownload = channel.unary_unary(
                '/voltha.VolthaService/CancelImageDownload',
                request_serializer=voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
                response_deserializer=voltha__protos_dot_common__pb2.OperationResp.FromString,
                )
        self.ActivateImageUpdate = channel.unary_unary(
                '/voltha.VolthaService/ActivateImageUpdate',
                request_serializer=voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
                response_deserializer=voltha__protos_dot_common__pb2.OperationResp.FromString,
                )
        self.RevertImageUpdate = channel.unary_unary(
                '/voltha.VolthaService/RevertImageUpdate',
                request_serializer=voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
                response_deserializer=voltha__protos_dot_common__pb2.OperationResp.FromString,
                )
        self.ListDevicePorts = channel.unary_unary(
                '/voltha.VolthaService/ListDevicePorts',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.Ports.FromString,
                )
        self.ListDevicePmConfigs = channel.unary_unary(
                '/voltha.VolthaService/ListDevicePmConfigs',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.PmConfigs.FromString,
                )
        self.UpdateDevicePmConfigs = channel.unary_unary(
                '/voltha.VolthaService/UpdateDevicePmConfigs',
                request_serializer=voltha__protos_dot_device__pb2.PmConfigs.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListDeviceFlows = channel.unary_unary(
                '/voltha.VolthaService/ListDeviceFlows',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_openflow__13__pb2.Flows.FromString,
                )
        self.ListDeviceFlowGroups = channel.unary_unary(
                '/voltha.VolthaService/ListDeviceFlowGroups',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_openflow__13__pb2.FlowGroups.FromString,
                )
        self.ListDeviceTypes = channel.unary_unary(
                '/voltha.VolthaService/ListDeviceTypes',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.DeviceTypes.FromString,
                )
        self.GetDeviceType = channel.unary_unary(
                '/voltha.VolthaService/GetDeviceType',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.DeviceType.FromString,
                )
        self.ListDeviceGroups = channel.unary_unary(
                '/voltha.VolthaService/ListDeviceGroups',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_voltha__pb2.DeviceGroups.FromString,
                )
        self.StreamPacketsOut = channel.stream_unary(
                '/voltha.VolthaService/StreamPacketsOut',
                request_serializer=voltha__protos_dot_openflow__13__pb2.PacketOut.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ReceivePacketsIn = channel.unary_stream(
                '/voltha.VolthaService/ReceivePacketsIn',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openflow__13__pb2.PacketIn.FromString,
                )
        self.ReceiveChangeEvents = channel.unary_stream(
                '/voltha.VolthaService/ReceiveChangeEvents',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_openflow__13__pb2.ChangeEvent.FromString,
                )
        self.GetDeviceGroup = channel.unary_unary(
                '/voltha.VolthaService/GetDeviceGroup',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_voltha__pb2.DeviceGroup.FromString,
                )
        self.CreateEventFilter = channel.unary_unary(
                '/voltha.VolthaService/CreateEventFilter',
                request_serializer=voltha__protos_dot_voltha__pb2.EventFilter.SerializeToString,
                response_deserializer=voltha__protos_dot_voltha__pb2.EventFilter.FromString,
                )
        self.GetEventFilter = channel.unary_unary(
                '/voltha.VolthaService/GetEventFilter',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_voltha__pb2.EventFilters.FromString,
                )
        self.UpdateEventFilter = channel.unary_unary(
                '/voltha.VolthaService/UpdateEventFilter',
                request_serializer=voltha__protos_dot_voltha__pb2.EventFilter.SerializeToString,
                response_deserializer=voltha__protos_dot_voltha__pb2.EventFilter.FromString,
                )
        self.DeleteEventFilter = channel.unary_unary(
                '/voltha.VolthaService/DeleteEventFilter',
                request_serializer=voltha__protos_dot_voltha__pb2.EventFilter.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListEventFilters = channel.unary_unary(
                '/voltha.VolthaService/ListEventFilters',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_voltha__pb2.EventFilters.FromString,
                )
        self.GetImages = channel.unary_unary(
                '/voltha.VolthaService/GetImages',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.Images.FromString,
                )
        self.SelfTest = channel.unary_unary(
                '/voltha.VolthaService/SelfTest',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_voltha__pb2.SelfTestResponse.FromString,
                )
        self.GetMibDeviceData = channel.unary_unary(
                '/voltha.VolthaService/GetMibDeviceData',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_omci__mib__db__pb2.MibDeviceData.FromString,
                )
        self.GetAlarmDeviceData = channel.unary_unary(
                '/voltha.VolthaService/GetAlarmDeviceData',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_omci__alarm__db__pb2.AlarmDeviceData.FromString,
                )
        self.SimulateAlarm = channel.unary_unary(
                '/voltha.VolthaService/SimulateAlarm',
                request_serializer=voltha__protos_dot_device__pb2.SimulateAlarmRequest.SerializeToString,
                response_deserializer=voltha__protos_dot_common__pb2.OperationResp.FromString,
                )
        self.Subscribe = channel.unary_unary(
                '/voltha.VolthaService/Subscribe',
                request_serializer=voltha__protos_dot_voltha__pb2.OfAgentSubscriber.SerializeToString,
                response_deserializer=voltha__protos_dot_voltha__pb2.OfAgentSubscriber.FromString,
                )
        self.EnablePort = channel.unary_unary(
                '/voltha.VolthaService/EnablePort',
                request_serializer=voltha__protos_dot_device__pb2.Port.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DisablePort = channel.unary_unary(
                '/voltha.VolthaService/DisablePort',
                request_serializer=voltha__protos_dot_device__pb2.Port.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetExtValue = channel.unary_unary(
                '/voltha.VolthaService/GetExtValue',
                request_serializer=voltha__protos_dot_common__pb2.ValueSpecifier.SerializeToString,
                response_deserializer=voltha__protos_dot_common__pb2.ReturnValues.FromString,
                )
        self.SetExtValue = channel.unary_unary(
                '/voltha.VolthaService/SetExtValue',
                request_serializer=voltha__protos_dot_voltha__pb2.ValueSet.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.StartOmciTestAction = channel.unary_unary(
                '/voltha.VolthaService/StartOmciTestAction',
                request_serializer=voltha__protos_dot_voltha__pb2.OmciTestRequest.SerializeToString,
                response_deserializer=voltha__protos_dot_voltha__pb2.TestResponse.FromString,
                )


class VolthaServiceServicer(object):
    """
    Voltha APIs

    """

    def GetMembership(self, request, context):
        """Get the membership group of a Voltha Core
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMembership(self, request, context):
        """Set the membership group of a Voltha Core
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVoltha(self, request, context):
        """Get high level information on the Voltha cluster
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCoreInstances(self, request, context):
        """List all Voltha cluster core instances
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCoreInstance(self, request, context):
        """Get details on a Voltha cluster instance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAdapters(self, request, context):
        """List all active adapters (plugins) in the Voltha cluster
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLogicalDevices(self, request, context):
        """List all logical devices managed by the Voltha cluster
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLogicalDevice(self, request, context):
        """Get additional information on a given logical device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLogicalDevicePorts(self, request, context):
        """List ports of a logical device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLogicalDevicePort(self, request, context):
        """Gets a logical device port
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableLogicalDevicePort(self, request, context):
        """Enables a logical device port
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableLogicalDevicePort(self, request, context):
        """Disables a logical device port
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLogicalDeviceFlows(self, request, context):
        """List all flows of a logical device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateLogicalDeviceFlowTable(self, request, context):
        """Update flow table for logical device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateLogicalDeviceMeterTable(self, request, context):
        """Update meter table for logical device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLogicalDeviceMeters(self, request, context):
        """List all meters of a logical device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLogicalDeviceFlowGroups(self, request, context):
        """List all flow groups of a logical device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateLogicalDeviceFlowGroupTable(self, request, context):
        """Update group table for device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDevices(self, request, context):
        """List all physical devices controlled by the Voltha cluster
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeviceIds(self, request, context):
        """List all physical devices IDs controlled by the Voltha cluster
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReconcileDevices(self, request, context):
        """Request to a voltha Core to reconcile a set of devices based on their IDs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDevice(self, request, context):
        """Get more information on a given physical device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDevice(self, request, context):
        """Pre-provision a new physical device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableDevice(self, request, context):
        """Enable a device.  If the device was in pre-provisioned state then it
        will transition to ENABLED state.  If it was is DISABLED state then it
        will transition to ENABLED state as well.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableDevice(self, request, context):
        """Disable a device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RebootDevice(self, request, context):
        """Reboot a device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDevice(self, request, context):
        """Delete a device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ForceDeleteDevice(self, request, context):
        """Forcefully delete a device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadImage(self, request, context):
        """Request an image download to the standby partition
        of a device.
        Note that the call is expected to be non-blocking.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetImageDownloadStatus(self, request, context):
        """Get image download status on a device
        The request retrieves progress on device and updates db record
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetImageDownload(self, request, context):
        """Get image download db record
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListImageDownloads(self, request, context):
        """List image download db records for a given device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelImageDownload(self, request, context):
        """Cancel an existing image download process on a device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateImageUpdate(self, request, context):
        """Activate the specified image at a standby partition
        to active partition.
        Depending on the device implementation, this call
        may or may not cause device reboot.
        If no reboot, then a reboot is required to make the
        activated image running on device
        Note that the call is expected to be non-blocking.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevertImageUpdate(self, request, context):
        """Revert the specified image at standby partition
        to active partition, and revert to previous image
        Depending on the device implementation, this call
        may or may not cause device reboot.
        If no reboot, then a reboot is required to make the
        previous image running on device
        Note that the call is expected to be non-blocking.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDevicePorts(self, request, context):
        """List ports of a device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDevicePmConfigs(self, request, context):
        """List pm config of a device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDevicePmConfigs(self, request, context):
        """Update the pm config of a device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeviceFlows(self, request, context):
        """List all flows of a device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeviceFlowGroups(self, request, context):
        """List all flow groups of a device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeviceTypes(self, request, context):
        """List device types known to Voltha
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceType(self, request, context):
        """Get additional information on a device type
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeviceGroups(self, request, context):
        """List all device sharding groups
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamPacketsOut(self, request_iterator, context):
        """Stream control packets to the dataplane
        This does not have an HTTP representation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReceivePacketsIn(self, request, context):
        """Receive control packet stream
        This does not have an HTTP representation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReceiveChangeEvents(self, request, context):
        """This does not have an HTTP representation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceGroup(self, request, context):
        """Get additional information on a device group
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEventFilter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEventFilter(self, request, context):
        """Get all filters present for a device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEventFilter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEventFilter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEventFilters(self, request, context):
        """Get all the filters present
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetImages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SelfTest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMibDeviceData(self, request, context):
        """OpenOMCI MIB information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAlarmDeviceData(self, request, context):
        """OpenOMCI ALARM information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SimulateAlarm(self, request, context):
        """Simulate an Alarm
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Subscribe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnablePort(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisablePort(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExtValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetExtValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartOmciTestAction(self, request, context):
        """omci start and stop cli implementation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VolthaServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMembership,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_voltha__pb2.Membership.SerializeToString,
            ),
            'UpdateMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMembership,
                    request_deserializer=voltha__protos_dot_voltha__pb2.Membership.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetVoltha': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVoltha,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_voltha__pb2.Voltha.SerializeToString,
            ),
            'ListCoreInstances': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCoreInstances,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_voltha__pb2.CoreInstances.SerializeToString,
            ),
            'GetCoreInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCoreInstance,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_voltha__pb2.CoreInstance.SerializeToString,
            ),
            'ListAdapters': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAdapters,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_adapter__pb2.Adapters.SerializeToString,
            ),
            'ListLogicalDevices': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLogicalDevices,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_logical__device__pb2.LogicalDevices.SerializeToString,
            ),
            'GetLogicalDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLogicalDevice,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_logical__device__pb2.LogicalDevice.SerializeToString,
            ),
            'ListLogicalDevicePorts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLogicalDevicePorts,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_logical__device__pb2.LogicalPorts.SerializeToString,
            ),
            'GetLogicalDevicePort': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLogicalDevicePort,
                    request_deserializer=voltha__protos_dot_logical__device__pb2.LogicalPortId.FromString,
                    response_serializer=voltha__protos_dot_logical__device__pb2.LogicalPort.SerializeToString,
            ),
            'EnableLogicalDevicePort': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableLogicalDevicePort,
                    request_deserializer=voltha__protos_dot_logical__device__pb2.LogicalPortId.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DisableLogicalDevicePort': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableLogicalDevicePort,
                    request_deserializer=voltha__protos_dot_logical__device__pb2.LogicalPortId.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListLogicalDeviceFlows': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLogicalDeviceFlows,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_openflow__13__pb2.Flows.SerializeToString,
            ),
            'UpdateLogicalDeviceFlowTable': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateLogicalDeviceFlowTable,
                    request_deserializer=voltha__protos_dot_openflow__13__pb2.FlowTableUpdate.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateLogicalDeviceMeterTable': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateLogicalDeviceMeterTable,
                    request_deserializer=voltha__protos_dot_openflow__13__pb2.MeterModUpdate.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListLogicalDeviceMeters': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLogicalDeviceMeters,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_openflow__13__pb2.Meters.SerializeToString,
            ),
            'ListLogicalDeviceFlowGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLogicalDeviceFlowGroups,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_openflow__13__pb2.FlowGroups.SerializeToString,
            ),
            'UpdateLogicalDeviceFlowGroupTable': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateLogicalDeviceFlowGroupTable,
                    request_deserializer=voltha__protos_dot_openflow__13__pb2.FlowGroupTableUpdate.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListDevices': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDevices,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.Devices.SerializeToString,
            ),
            'ListDeviceIds': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeviceIds,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_common__pb2.IDs.SerializeToString,
            ),
            'ReconcileDevices': grpc.unary_unary_rpc_method_handler(
                    servicer.ReconcileDevices,
                    request_deserializer=voltha__protos_dot_common__pb2.IDs.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDevice,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
            ),
            'CreateDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDevice,
                    request_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
            ),
            'EnableDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableDevice,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DisableDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableDevice,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RebootDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.RebootDevice,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDevice,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ForceDeleteDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.ForceDeleteDevice,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DownloadImage': grpc.unary_unary_rpc_method_handler(
                    servicer.DownloadImage,
                    request_deserializer=voltha__protos_dot_device__pb2.ImageDownload.FromString,
                    response_serializer=voltha__protos_dot_common__pb2.OperationResp.SerializeToString,
            ),
            'GetImageDownloadStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetImageDownloadStatus,
                    request_deserializer=voltha__protos_dot_device__pb2.ImageDownload.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
            ),
            'GetImageDownload': grpc.unary_unary_rpc_method_handler(
                    servicer.GetImageDownload,
                    request_deserializer=voltha__protos_dot_device__pb2.ImageDownload.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
            ),
            'ListImageDownloads': grpc.unary_unary_rpc_method_handler(
                    servicer.ListImageDownloads,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.ImageDownloads.SerializeToString,
            ),
            'CancelImageDownload': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelImageDownload,
                    request_deserializer=voltha__protos_dot_device__pb2.ImageDownload.FromString,
                    response_serializer=voltha__protos_dot_common__pb2.OperationResp.SerializeToString,
            ),
            'ActivateImageUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateImageUpdate,
                    request_deserializer=voltha__protos_dot_device__pb2.ImageDownload.FromString,
                    response_serializer=voltha__protos_dot_common__pb2.OperationResp.SerializeToString,
            ),
            'RevertImageUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.RevertImageUpdate,
                    request_deserializer=voltha__protos_dot_device__pb2.ImageDownload.FromString,
                    response_serializer=voltha__protos_dot_common__pb2.OperationResp.SerializeToString,
            ),
            'ListDevicePorts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDevicePorts,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.Ports.SerializeToString,
            ),
            'ListDevicePmConfigs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDevicePmConfigs,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.PmConfigs.SerializeToString,
            ),
            'UpdateDevicePmConfigs': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDevicePmConfigs,
                    request_deserializer=voltha__protos_dot_device__pb2.PmConfigs.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListDeviceFlows': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeviceFlows,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_openflow__13__pb2.Flows.SerializeToString,
            ),
            'ListDeviceFlowGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeviceFlowGroups,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_openflow__13__pb2.FlowGroups.SerializeToString,
            ),
            'ListDeviceTypes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeviceTypes,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.DeviceTypes.SerializeToString,
            ),
            'GetDeviceType': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeviceType,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.DeviceType.SerializeToString,
            ),
            'ListDeviceGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeviceGroups,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_voltha__pb2.DeviceGroups.SerializeToString,
            ),
            'StreamPacketsOut': grpc.stream_unary_rpc_method_handler(
                    servicer.StreamPacketsOut,
                    request_deserializer=voltha__protos_dot_openflow__13__pb2.PacketOut.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ReceivePacketsIn': grpc.unary_stream_rpc_method_handler(
                    servicer.ReceivePacketsIn,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openflow__13__pb2.PacketIn.SerializeToString,
            ),
            'ReceiveChangeEvents': grpc.unary_stream_rpc_method_handler(
                    servicer.ReceiveChangeEvents,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_openflow__13__pb2.ChangeEvent.SerializeToString,
            ),
            'GetDeviceGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeviceGroup,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_voltha__pb2.DeviceGroup.SerializeToString,
            ),
            'CreateEventFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEventFilter,
                    request_deserializer=voltha__protos_dot_voltha__pb2.EventFilter.FromString,
                    response_serializer=voltha__protos_dot_voltha__pb2.EventFilter.SerializeToString,
            ),
            'GetEventFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEventFilter,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_voltha__pb2.EventFilters.SerializeToString,
            ),
            'UpdateEventFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEventFilter,
                    request_deserializer=voltha__protos_dot_voltha__pb2.EventFilter.FromString,
                    response_serializer=voltha__protos_dot_voltha__pb2.EventFilter.SerializeToString,
            ),
            'DeleteEventFilter': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEventFilter,
                    request_deserializer=voltha__protos_dot_voltha__pb2.EventFilter.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListEventFilters': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEventFilters,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_voltha__pb2.EventFilters.SerializeToString,
            ),
            'GetImages': grpc.unary_unary_rpc_method_handler(
                    servicer.GetImages,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.Images.SerializeToString,
            ),
            'SelfTest': grpc.unary_unary_rpc_method_handler(
                    servicer.SelfTest,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_voltha__pb2.SelfTestResponse.SerializeToString,
            ),
            'GetMibDeviceData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMibDeviceData,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_omci__mib__db__pb2.MibDeviceData.SerializeToString,
            ),
            'GetAlarmDeviceData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAlarmDeviceData,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_omci__alarm__db__pb2.AlarmDeviceData.SerializeToString,
            ),
            'SimulateAlarm': grpc.unary_unary_rpc_method_handler(
                    servicer.SimulateAlarm,
                    request_deserializer=voltha__protos_dot_device__pb2.SimulateAlarmRequest.FromString,
                    response_serializer=voltha__protos_dot_common__pb2.OperationResp.SerializeToString,
            ),
            'Subscribe': grpc.unary_unary_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=voltha__protos_dot_voltha__pb2.OfAgentSubscriber.FromString,
                    response_serializer=voltha__protos_dot_voltha__pb2.OfAgentSubscriber.SerializeToString,
            ),
            'EnablePort': grpc.unary_unary_rpc_method_handler(
                    servicer.EnablePort,
                    request_deserializer=voltha__protos_dot_device__pb2.Port.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DisablePort': grpc.unary_unary_rpc_method_handler(
                    servicer.DisablePort,
                    request_deserializer=voltha__protos_dot_device__pb2.Port.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetExtValue': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExtValue,
                    request_deserializer=voltha__protos_dot_common__pb2.ValueSpecifier.FromString,
                    response_serializer=voltha__protos_dot_common__pb2.ReturnValues.SerializeToString,
            ),
            'SetExtValue': grpc.unary_unary_rpc_method_handler(
                    servicer.SetExtValue,
                    request_deserializer=voltha__protos_dot_voltha__pb2.ValueSet.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'StartOmciTestAction': grpc.unary_unary_rpc_method_handler(
                    servicer.StartOmciTestAction,
                    request_deserializer=voltha__protos_dot_voltha__pb2.OmciTestRequest.FromString,
                    response_serializer=voltha__protos_dot_voltha__pb2.TestResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'voltha.VolthaService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class VolthaService(object):
    """
    Voltha APIs

    """

    @staticmethod
    def GetMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetMembership',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_voltha__pb2.Membership.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/UpdateMembership',
            voltha__protos_dot_voltha__pb2.Membership.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVoltha(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetVoltha',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_voltha__pb2.Voltha.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCoreInstances(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListCoreInstances',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_voltha__pb2.CoreInstances.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCoreInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetCoreInstance',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_voltha__pb2.CoreInstance.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAdapters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListAdapters',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_adapter__pb2.Adapters.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLogicalDevices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListLogicalDevices',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_logical__device__pb2.LogicalDevices.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLogicalDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetLogicalDevice',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_logical__device__pb2.LogicalDevice.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLogicalDevicePorts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListLogicalDevicePorts',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_logical__device__pb2.LogicalPorts.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLogicalDevicePort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetLogicalDevicePort',
            voltha__protos_dot_logical__device__pb2.LogicalPortId.SerializeToString,
            voltha__protos_dot_logical__device__pb2.LogicalPort.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableLogicalDevicePort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/EnableLogicalDevicePort',
            voltha__protos_dot_logical__device__pb2.LogicalPortId.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableLogicalDevicePort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/DisableLogicalDevicePort',
            voltha__protos_dot_logical__device__pb2.LogicalPortId.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLogicalDeviceFlows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListLogicalDeviceFlows',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_openflow__13__pb2.Flows.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateLogicalDeviceFlowTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/UpdateLogicalDeviceFlowTable',
            voltha__protos_dot_openflow__13__pb2.FlowTableUpdate.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateLogicalDeviceMeterTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/UpdateLogicalDeviceMeterTable',
            voltha__protos_dot_openflow__13__pb2.MeterModUpdate.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLogicalDeviceMeters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListLogicalDeviceMeters',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_openflow__13__pb2.Meters.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLogicalDeviceFlowGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListLogicalDeviceFlowGroups',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_openflow__13__pb2.FlowGroups.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateLogicalDeviceFlowGroupTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/UpdateLogicalDeviceFlowGroupTable',
            voltha__protos_dot_openflow__13__pb2.FlowGroupTableUpdate.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDevices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListDevices',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_device__pb2.Devices.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDeviceIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListDeviceIds',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_common__pb2.IDs.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReconcileDevices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ReconcileDevices',
            voltha__protos_dot_common__pb2.IDs.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetDevice',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_device__pb2.Device.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/CreateDevice',
            voltha__protos_dot_device__pb2.Device.SerializeToString,
            voltha__protos_dot_device__pb2.Device.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/EnableDevice',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/DisableDevice',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RebootDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/RebootDevice',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/DeleteDevice',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ForceDeleteDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ForceDeleteDevice',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DownloadImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/DownloadImage',
            voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
            voltha__protos_dot_common__pb2.OperationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetImageDownloadStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetImageDownloadStatus',
            voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
            voltha__protos_dot_device__pb2.ImageDownload.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetImageDownload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetImageDownload',
            voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
            voltha__protos_dot_device__pb2.ImageDownload.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListImageDownloads(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListImageDownloads',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_device__pb2.ImageDownloads.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelImageDownload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/CancelImageDownload',
            voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
            voltha__protos_dot_common__pb2.OperationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateImageUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ActivateImageUpdate',
            voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
            voltha__protos_dot_common__pb2.OperationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevertImageUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/RevertImageUpdate',
            voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
            voltha__protos_dot_common__pb2.OperationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDevicePorts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListDevicePorts',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_device__pb2.Ports.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDevicePmConfigs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListDevicePmConfigs',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_device__pb2.PmConfigs.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDevicePmConfigs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/UpdateDevicePmConfigs',
            voltha__protos_dot_device__pb2.PmConfigs.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDeviceFlows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListDeviceFlows',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_openflow__13__pb2.Flows.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDeviceFlowGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListDeviceFlowGroups',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_openflow__13__pb2.FlowGroups.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDeviceTypes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListDeviceTypes',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_device__pb2.DeviceTypes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeviceType(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetDeviceType',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_device__pb2.DeviceType.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDeviceGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListDeviceGroups',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_voltha__pb2.DeviceGroups.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamPacketsOut(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/voltha.VolthaService/StreamPacketsOut',
            voltha__protos_dot_openflow__13__pb2.PacketOut.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReceivePacketsIn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/voltha.VolthaService/ReceivePacketsIn',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_openflow__13__pb2.PacketIn.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReceiveChangeEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/voltha.VolthaService/ReceiveChangeEvents',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_openflow__13__pb2.ChangeEvent.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeviceGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetDeviceGroup',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_voltha__pb2.DeviceGroup.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEventFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/CreateEventFilter',
            voltha__protos_dot_voltha__pb2.EventFilter.SerializeToString,
            voltha__protos_dot_voltha__pb2.EventFilter.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEventFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetEventFilter',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_voltha__pb2.EventFilters.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEventFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/UpdateEventFilter',
            voltha__protos_dot_voltha__pb2.EventFilter.SerializeToString,
            voltha__protos_dot_voltha__pb2.EventFilter.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEventFilter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/DeleteEventFilter',
            voltha__protos_dot_voltha__pb2.EventFilter.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEventFilters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/ListEventFilters',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_voltha__pb2.EventFilters.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetImages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetImages',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_device__pb2.Images.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SelfTest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/SelfTest',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_voltha__pb2.SelfTestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMibDeviceData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetMibDeviceData',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_omci__mib__db__pb2.MibDeviceData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAlarmDeviceData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetAlarmDeviceData',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_omci__alarm__db__pb2.AlarmDeviceData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SimulateAlarm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/SimulateAlarm',
            voltha__protos_dot_device__pb2.SimulateAlarmRequest.SerializeToString,
            voltha__protos_dot_common__pb2.OperationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/Subscribe',
            voltha__protos_dot_voltha__pb2.OfAgentSubscriber.SerializeToString,
            voltha__protos_dot_voltha__pb2.OfAgentSubscriber.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnablePort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/EnablePort',
            voltha__protos_dot_device__pb2.Port.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisablePort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/DisablePort',
            voltha__protos_dot_device__pb2.Port.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExtValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/GetExtValue',
            voltha__protos_dot_common__pb2.ValueSpecifier.SerializeToString,
            voltha__protos_dot_common__pb2.ReturnValues.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetExtValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/SetExtValue',
            voltha__protos_dot_voltha__pb2.ValueSet.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartOmciTestAction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.VolthaService/StartOmciTestAction',
            voltha__protos_dot_voltha__pb2.OmciTestRequest.SerializeToString,
            voltha__protos_dot_voltha__pb2.TestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2


class HealthServiceStub(object):
    """Health related services
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetHealthStatus = channel.unary_unary(
                '/voltha.HealthService/GetHealthStatus',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=voltha__protos_dot_health__pb2.HealthStatus.FromString,
                )


class HealthServiceServicer(object):
    """Health related services
    """

    def GetHealthStatus(self, request, context):
        """Return current health status of a Voltha instance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HealthServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetHealthStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHealthStatus,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=voltha__protos_dot_health__pb2.HealthStatus.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'voltha.HealthService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class HealthService(object):
    """Health related services
    """

    @staticmethod
    def GetHealthStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/voltha.HealthService/GetHealthStatus',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            voltha__protos_dot_health__pb2.HealthStatus.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/ietf_interfaces.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/ietf_interfaces.proto',
  package='ietf',
  syntax='proto3',
  serialized_options=b'\n\023org.opencord.volthaZ,github.com/opencord/voltha-protos/v3/go/ietf',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#voltha_protos/ietf_interfaces.proto\x12\x04ietf\"5\n\nInterfaces\x12\'\n\x0e\x61ll_interfaces\x18\x01 \x03(\x0b\x32\x0f.ietf.Interface\"\xda\x01\n\tInterface\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12J\n\x18link_up_down_trap_enable\x18\x05 \x01(\x0e\x32(.ietf.Interface.LinkUpDownTrapEnableType\"?\n\x18LinkUpDownTrapEnableType\x12\x11\n\rTRAP_DISABLED\x10\x00\x12\x10\n\x0cTRAP_ENABLED\x10\x01\">\n\x0fInterfacesState\x12+\n\rall_interfacs\x18\x01 \x03(\x0b\x32\x14.ietf.InterfaceState\"\xd5\x03\n\x0eInterfaceState\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12:\n\x0c\x61\x64min_status\x18\x03 \x01(\x0e\x32$.ietf.InterfaceState.AdminStatusType\x12\x38\n\x0boper_status\x18\x04 \x01(\x0e\x32#.ietf.InterfaceState.OperStatusType\x12\x13\n\x0blast_change\x18\x05 \x01(\t\x12\x10\n\x08if_index\x18\x06 \x01(\x05\x12\x14\n\x0cphys_address\x18\x07 \x01(\t\x12\x17\n\x0fhigher_layer_if\x18\x08 \x03(\t\x12\x16\n\x0elower_layer_if\x18\t \x03(\t\x12\r\n\x05speed\x18\n \x01(\x04\"B\n\x0f\x41\x64minStatusType\x12\x0e\n\nADMIN_DOWN\x10\x00\x12\x11\n\rADMIN_TESTING\x10\x01\x12\x0c\n\x08\x41\x44MIN_UP\x10\x02\"p\n\x0eOperStatusType\x12\x0b\n\x07\x44ORMANT\x10\x00\x12\x14\n\x10LOWER_LAYER_DOWN\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\x06\n\x02UP\x10\x04\x12\x08\n\x04\x44OWN\x10\x05\x12\x0f\n\x0bNOT_PRESENT\x10\x06\x42\x43\n\x13org.opencord.volthaZ,github.com/opencord/voltha-protos/v3/go/ietfb\x06proto3'
)



_INTERFACE_LINKUPDOWNTRAPENABLETYPE = _descriptor.EnumDescriptor(
  name='LinkUpDownTrapEnableType',
  full_name='ietf.Interface.LinkUpDownTrapEnableType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRAP_DISABLED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAP_ENABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=256,
  serialized_end=319,
)
_sym_db.RegisterEnumDescriptor(_INTERFACE_LINKUPDOWNTRAPENABLETYPE)

_INTERFACESTATE_ADMINSTATUSTYPE = _descriptor.EnumDescriptor(
  name='AdminStatusType',
  full_name='ietf.InterfaceState.AdminStatusType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADMIN_DOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADMIN_TESTING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADMIN_UP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=675,
  serialized_end=741,
)
_sym_db.RegisterEnumDescriptor(_INTERFACESTATE_ADMINSTATUSTYPE)

_INTERFACESTATE_OPERSTATUSTYPE = _descriptor.EnumDescriptor(
  name='OperStatusType',
  full_name='ietf.InterfaceState.OperStatusType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DORMANT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOWER_LAYER_DOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TESTING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_PRESENT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=743,
  serialized_end=855,
)
_sym_db.RegisterEnumDescriptor(_INTERFACESTATE_OPERSTATUSTYPE)


_INTERFACES = _descriptor.Descriptor(
  name='Interfaces',
  full_name='ietf.Interfaces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='all_interfaces', full_name='ietf.Interfaces.all_interfaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=98,
)


_INTERFACE = _descriptor.Descriptor(
  name='Interface',
  full_name='ietf.Interface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ietf.Interface.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ietf.Interface.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='ietf.Interface.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='ietf.Interface.enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_up_down_trap_enable', full_name='ietf.Interface.link_up_down_trap_enable', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INTERFACE_LINKUPDOWNTRAPENABLETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=319,
)


_INTERFACESSTATE = _descriptor.Descriptor(
  name='InterfacesState',
  full_name='ietf.InterfacesState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='all_interfacs', full_name='ietf.InterfacesState.all_interfacs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=321,
  serialized_end=383,
)


_INTERFACESTATE = _descriptor.Descriptor(
  name='InterfaceState',
  full_name='ietf.InterfaceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ietf.InterfaceState.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='ietf.InterfaceState.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin_status', full_name='ietf.InterfaceState.admin_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oper_status', full_name='ietf.InterfaceState.oper_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_change', full_name='ietf.InterfaceState.last_change', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='if_index', full_name='ietf.InterfaceState.if_index', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phys_address', full_name='ietf.InterfaceState.phys_address', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='higher_layer_if', full_name='ietf.InterfaceState.higher_layer_if', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lower_layer_if', full_name='ietf.InterfaceState.lower_layer_if', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='ietf.InterfaceState.speed', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INTERFACESTATE_ADMINSTATUSTYPE,
    _INTERFACESTATE_OPERSTATUSTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=855,
)

_INTERFACES.fields_by_name['all_interfaces'].message_type = _INTERFACE
_INTERFACE.fields_by_name['link_up_down_trap_enable'].enum_type = _INTERFACE_LINKUPDOWNTRAPENABLETYPE
_INTERFACE_LINKUPDOWNTRAPENABLETYPE.containing_type = _INTERFACE
_INTERFACESSTATE.fields_by_name['all_interfacs'].message_type = _INTERFACESTATE
_INTERFACESTATE.fields_by_name['admin_status'].enum_type = _INTERFACESTATE_ADMINSTATUSTYPE
_INTERFACESTATE.fields_by_name['oper_status'].enum_type = _INTERFACESTATE_OPERSTATUSTYPE
_INTERFACESTATE_ADMINSTATUSTYPE.containing_type = _INTERFACESTATE
_INTERFACESTATE_OPERSTATUSTYPE.containing_type = _INTERFACESTATE
DESCRIPTOR.message_types_by_name['Interfaces'] = _INTERFACES
DESCRIPTOR.message_types_by_name['Interface'] = _INTERFACE
DESCRIPTOR.message_types_by_name['InterfacesState'] = _INTERFACESSTATE
DESCRIPTOR.message_types_by_name['InterfaceState'] = _INTERFACESTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Interfaces = _reflection.GeneratedProtocolMessageType('Interfaces', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACES,
  '__module__' : 'voltha_protos.ietf_interfaces_pb2'
  # @@protoc_insertion_point(class_scope:ietf.Interfaces)
  })
_sym_db.RegisterMessage(Interfaces)

Interface = _reflection.GeneratedProtocolMessageType('Interface', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACE,
  '__module__' : 'voltha_protos.ietf_interfaces_pb2'
  # @@protoc_insertion_point(class_scope:ietf.Interface)
  })
_sym_db.RegisterMessage(Interface)

InterfacesState = _reflection.GeneratedProtocolMessageType('InterfacesState', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACESSTATE,
  '__module__' : 'voltha_protos.ietf_interfaces_pb2'
  # @@protoc_insertion_point(class_scope:ietf.InterfacesState)
  })
_sym_db.RegisterMessage(InterfacesState)

InterfaceState = _reflection.GeneratedProtocolMessageType('InterfaceState', (_message.Message,), {
  'DESCRIPTOR' : _INTERFACESTATE,
  '__module__' : 'voltha_protos.ietf_interfaces_pb2'
  # @@protoc_insertion_point(class_scope:ietf.InterfaceState)
  })
_sym_db.RegisterMessage(InterfaceState)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
